@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -35,7 +35,7 @@
 #include <list>
 #include <map>
 #include <QtCore/QObject>
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
 using std::list;
 using std::map;
