@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -24,7 +24,7 @@
 #include "menuconf.h"
 #include <QtCore/QObject>
 #include <QtGui/QKeySequence>
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
 #include "selectfreecmd.h"
 #include "model.h"
