@@ -136,7 +136,7 @@ ModelViewport::ModelViewport( QWidget * parent )
 
    m_backColor.setRgb( 130, 200, 200 );
 
-   setAcceptDrops( true );
+   //setAcceptDrops( true ); // Drag and drop is not implemented, see ModelViewport::dragEnterEvent.
    setMouseTracking( true );
 
    connect( m_scrollTimer, SIGNAL(timeout()), this, SLOT(scrollTimeout()));
@@ -434,17 +434,17 @@ void ModelViewport::paintGL()
          if ( drawSelections )
          {
             glDisable( GL_LIGHTING );
-            m_model->drawLines();
-            m_model->drawVertices();
+            m_model->drawLines( devicePixelRatioF() );
+            m_model->drawVertices( devicePixelRatioF() );
 
             glDisable( GL_DEPTH_TEST );
-            m_model->drawJoints();
+            m_model->drawJoints( devicePixelRatioF() );
          }
 
          glDisable( GL_LIGHTING );
          glDisable( GL_DEPTH_TEST );
-         m_model->drawPoints();
-         m_model->drawProjections();
+         m_model->drawPoints( devicePixelRatioF() );
+         m_model->drawProjections( devicePixelRatioF() );
       }
       else
       {
@@ -485,16 +485,16 @@ void ModelViewport::paintGL()
             glPolygonOffset( 0, 0 );
          }
 
-         m_model->drawLines();
-         m_model->drawVertices();
+         m_model->drawLines( devicePixelRatioF() );
+         m_model->drawVertices( devicePixelRatioF() );
 
          glDisable( GL_DEPTH_TEST );
-         m_model->drawJoints();
-         m_model->drawPoints();
-         m_model->drawProjections();
+         m_model->drawJoints( devicePixelRatioF() );
+         m_model->drawPoints( devicePixelRatioF() );
+         m_model->drawProjections( devicePixelRatioF() );
          for ( DecalList::iterator it = m_decals.begin(); it != m_decals.end(); it++ )
          {
-            (*it)->draw();
+            (*it)->draw( devicePixelRatioF() );
          }
          glEnable( GL_DEPTH_TEST );
       }
@@ -532,6 +532,7 @@ void ModelViewport::drawGridLines()
       double y;
       double z;
 
+      glLineWidth( devicePixelRatioF() );
       glColor3f( 0.55f, 0.55f, 0.55f );
 
       glBegin( GL_LINES );
@@ -598,6 +599,7 @@ void ModelViewport::drawGridLines()
       double x = 0;
       double y = 0;
 
+      glLineWidth( devicePixelRatioF() );
       glColor3f( 0.55f, 0.55f, 0.55f );
 
       glBegin( GL_LINES );
@@ -792,6 +794,8 @@ void ModelViewport::drawOrigin()
 {
    glDisable( GL_DEPTH_TEST );
 
+   glLineWidth( devicePixelRatioF() );
+
    glBegin( GL_LINES );
 
    double scale = m_zoomLevel / 10.0;
@@ -1685,12 +1689,12 @@ void ModelViewport::mouseMoveEvent( QMouseEvent * e )
       QPoint curPos = e->pos();
 
       double xDiff = m_scrollStartPosition.x() - curPos.x();
-      xDiff = xDiff * (m_width / m_viewportWidth);
+      xDiff = xDiff * (m_width / this->width());
       m_centerX += xDiff;
 
       double yDiff = m_scrollStartPosition.y() - curPos.y();
       yDiff = -yDiff;  // Adjust for difference between pixel and GL coordinates
-      yDiff = yDiff * (m_height / m_viewportHeight);
+      yDiff = yDiff * (m_height / this->height());
       m_centerY += yDiff;
 
       //m_viewMatrix.inverseRotateVector( vec );
@@ -1719,11 +1723,11 @@ void ModelViewport::mouseMoveEvent( QMouseEvent * e )
       QPoint curPos = e->pos();
 
       double xDiff = m_scrollStartPosition.x() - curPos.x();
-      m_centerX += xDiff * (m_width / m_viewportWidth);
+      m_centerX += xDiff * (m_width / this->width());
 
       double yDiff = m_scrollStartPosition.y() - curPos.y();
       yDiff = -yDiff;  // Adjust for difference between pixel and GL coordinates
-      m_centerY += yDiff * (m_height / m_viewportHeight);
+      m_centerY += yDiff * (m_height / this->height());
 
       m_scrollStartPosition = curPos;
 #endif // NEWVIEWPORT
@@ -1816,12 +1820,12 @@ void ModelViewport::mouseMoveEvent( QMouseEvent * e )
                QPoint curPos = e->pos();
 
                double xDiff = m_scrollStartPosition.x() - curPos.x();
-               xDiff = xDiff * (m_width / m_viewportWidth);
+               xDiff = xDiff * (m_width / this->width());
                m_centerX += xDiff;
 
                double yDiff = m_scrollStartPosition.y() - curPos.y();
                yDiff = -yDiff;  // Adjust for difference between pixel and GL coordinates
-               yDiff = yDiff * (m_height / m_viewportHeight);
+               yDiff = yDiff * (m_height / this->height());
                m_centerY += yDiff;
 
                //m_viewMatrix.inverseRotateVector( vec );
@@ -1850,11 +1854,11 @@ void ModelViewport::mouseMoveEvent( QMouseEvent * e )
                QPoint curPos = e->pos();
 
                double xDiff = m_scrollStartPosition.x() - curPos.x();
-               m_centerX += xDiff * (m_width / m_viewportWidth);
+               m_centerX += xDiff * (m_width / this->width());
 
                double yDiff = m_scrollStartPosition.y() - curPos.y();
                yDiff = -yDiff;  // Adjust for difference between pixel and GL coordinates
-               m_centerY += yDiff * (m_height / m_viewportHeight);
+               m_centerY += yDiff * (m_height / this->height());
 
                m_scrollStartPosition = curPos;
 #endif // NEWVIEWPORT
@@ -1881,12 +1885,12 @@ void ModelViewport::mouseMoveEvent( QMouseEvent * e )
          QPoint curPos = e->pos();
 
          double xDiff = m_scrollStartPosition.x() - curPos.x();
-         xDiff = xDiff * (m_width / m_viewportWidth);
+         xDiff = xDiff * (m_width / this->width());
          m_centerX += xDiff;
 
          double yDiff = m_scrollStartPosition.y() - curPos.y();
          yDiff = -yDiff;  // Adjust for difference between pixel and GL coordinates
-         yDiff = yDiff * (m_height / m_viewportHeight);
+         yDiff = yDiff * (m_height / this->height());
          m_centerY += yDiff;
 
          m_arcballPoint[0] += xDiff;
@@ -2393,12 +2397,12 @@ void ModelViewport::dragEnterEvent( QDragMoveEvent * e )
 
 void ModelViewport::getParentXYValue( int x, int y, double & xval, double & yval, bool selected )
 {
-   xval = (((double) x / (double) m_viewportWidth)  * m_width)
+   xval = (((double) x / (double) this->width())  * m_width)
       - (m_width / 2.0);
-   yval = (((double) -y / (double) m_viewportHeight) * m_height)
+   yval = (((double) -y / (double) this->height()) * m_height)
       + (m_height / 2.0);
 
-   double maxDist = (4.1 / (double) m_viewportWidth) * m_width;
+   double maxDist = (4.1 / (double) this->width()) * m_width;
 
    if ( g_prefs.exists( "ui_snap_vertex" ) 
          &&  g_prefs( "ui_snap_vertex" ).intValue() != 0 )
@@ -2599,9 +2603,9 @@ void ModelViewport::getParentXYValue( int x, int y, double & xval, double & yval
 
 void ModelViewport::getRawParentXYValue( int x, int y, double & xval, double & yval )
 {
-   xval = (((double) x / (double) m_viewportWidth)  * m_width)
+   xval = (((double) x / (double) this->width())  * m_width)
       - (m_width / 2.0);
-   yval = (((double) -y / (double) m_viewportHeight) * m_height)
+   yval = (((double) -y / (double) this->height()) * m_height)
       + (m_height / 2.0);
 }
 
@@ -2609,8 +2613,8 @@ void ModelViewport::getRawParentXYValue( int x, int y, double & xval, double & y
 bool ModelViewport::getXValue( int x, int y, double * val )
 {
    Vector vec;
-   vec[0] =  (((double) x / (double) m_viewportWidth)  * m_width)  - (m_width  / 2.0);
-   vec[1] = -((((double) y / (double) m_viewportHeight) * m_height) - (m_height / 2.0));
+   vec[0] =  (((double) x / (double) this->width())  * m_width)  - (m_width  / 2.0);
+   vec[1] = -((((double) y / (double) this->height()) * m_height) - (m_height / 2.0));
    vec[2] = 0.0;
 
    m_invMatrix.apply( vec );
@@ -2635,8 +2639,8 @@ bool ModelViewport::getXValue( int x, int y, double * val )
 bool ModelViewport::getYValue( int x, int y, double * val )
 {
    Vector vec;
-   vec[0] =  (((double) x / (double) m_viewportWidth)  * m_width)  - (m_width  / 2.0);
-   vec[1] = -((((double) y / (double) m_viewportHeight) * m_height) - (m_height / 2.0));
+   vec[0] =  (((double) x / (double) this->width())  * m_width)  - (m_width  / 2.0);
+   vec[1] = -((((double) y / (double) this->height()) * m_height) - (m_height / 2.0));
    vec[2] = 0.0;
 
    m_invMatrix.apply( vec );
@@ -2661,8 +2665,8 @@ bool ModelViewport::getYValue( int x, int y, double * val )
 bool ModelViewport::getZValue( int x, int y, double * val )
 {
    Vector vec;
-   vec[0] =  (((double) x / (double) m_viewportWidth)  * m_width)  - (m_width  / 2.0);
-   vec[1] = -((((double) y / (double) m_viewportHeight) * m_height) - (m_height / 2.0));
+   vec[0] =  (((double) x / (double) this->width())  * m_width)  - (m_width  / 2.0);
+   vec[1] = -((((double) y / (double) this->height()) * m_height) - (m_height / 2.0));
    vec[2] = 0.0;
 
    m_invMatrix.apply( vec );
@@ -2692,10 +2696,10 @@ bool ModelViewport::getXValue( int x, int y, double * val )
       case ViewFront:
       case ViewTop:
       case ViewBottom:
-         *val = (m_centerX - (m_width / 2.0)) + (((double) x / (double) m_viewportWidth) * m_width);
+         *val = (m_centerX - (m_width / 2.0)) + (((double) x / (double) this->width()) * m_width);
          break;
       case ViewBack:
-         *val = ((-m_centerX) + (m_width / 2.0)) + (((double) (-x) / (double) m_viewportWidth) * m_width);
+         *val = ((-m_centerX) + (m_width / 2.0)) + (((double) (-x) / (double) this->width()) * m_width);
          break;
       case ViewRight:
       case ViewLeft:
@@ -2714,7 +2718,7 @@ bool ModelViewport::getYValue( int x, int y, double * val )
       case ViewBack:
       case ViewRight:
       case ViewLeft:
-         *val = (m_centerY + (m_height / 2.0)) - (((double) y / (double) m_viewportHeight) * m_height);
+         *val = (m_centerY + (m_height / 2.0)) - (((double) y / (double) this->height()) * m_height);
          break;
       case ViewTop:
       case ViewBottom:
@@ -2731,17 +2735,16 @@ bool ModelViewport::getZValue( int x, int y, double * val )
    switch ( m_viewDirection )
    {
       case ViewTop:
-         *val = ((-m_centerY) - (m_height / 2.0)) - (((double) (-y) / (double) m_viewportHeight) * m_height);
+         *val = ((-m_centerY) - (m_height / 2.0)) - (((double) (-y) / (double) this->height()) * m_height);
          break;
       case ViewBottom:
-         *val = (m_centerY + (m_height / 2.0)) - (((double) y / (double) m_viewportHeight) * m_height);
-         //*val = (m_centerY + (m_height / 2.0)) - (((double) y / (double) m_viewportHeight) * m_height);
+         *val = (m_centerY + (m_height / 2.0)) - (((double) y / (double) this->height()) * m_height);
          break;
       case ViewRight:
-         *val = (m_centerX - (m_width / 2.0)) + (((double) x / (double) m_viewportWidth) * m_width);
+         *val = (m_centerX - (m_width / 2.0)) + (((double) x / (double) this->width()) * m_width);
          break;
       case ViewLeft:
-         *val = ((-m_centerX) + (m_width / 2.0)) + (((double) (-x) / (double) m_viewportWidth) * m_width);
+         *val = ((-m_centerX) + (m_width / 2.0)) + (((double) (-x) / (double) this->width()) * m_width);
          break;
       case ViewFront:
       case ViewBack:
@@ -3078,8 +3081,8 @@ void ModelViewport::copyContentsToTexture( Texture * tex )
    m_capture = true;
    if ( tex )
    {
-      unsigned w = this->width();
-      unsigned h = this->height();
+      unsigned w = m_viewportWidth;
+      unsigned h = m_viewportHeight;
 
       // make sure texture can hold data
 
