@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -24,6 +24,9 @@
 #ifndef __TEXWIDGET_H
 #define __TEXWIDGET_H
 
+#include <stdint.h>
+
+#include <QtCore/QtGlobal>
 #include <QtOpenGL/QGLWidget>
 #include <QtGui/QWheelEvent>
 #include <QtGui/QMouseEvent>
@@ -116,6 +119,7 @@ class TextureWidget : public QGLWidget
 
       void setDrawMode( DrawModeE dm );
       void setDrawVertices( bool dv ) { m_drawVertices = dv; };
+      void setDrawBorder( bool db ) { m_drawBorder = db; };
       void setMouseOperation( MouseOperationE op );
 
       void setScaleKeepAspect( bool o ) { m_scaleKeepAspect = o; };
@@ -123,12 +127,23 @@ class TextureWidget : public QGLWidget
 
       void setSolidBackground( bool o ) { m_solidBackground = o; };
 
+      void vFlipCoordinates();
+      void hFlipCoordinates();
+      void rotateCoordinatesCcw();
+      void rotateCoordinatesCw();
+
+      void setLinesColor( uint32_t newColor ) { m_linesColor = newColor; }
+      void setSelectionColor( uint32_t newColor ) { m_selectionColor = newColor; }
+
       int  addVertex( double t, double s );
       int  addTriangle( int v1, int v2, int v3 );
 
       void clearCoordinates();
       void getCoordinates( int tri, float * s, float * t );
 
+      void saveSelectedUv();
+      void restoreSelectedUv();
+
       // This is min/max of the current viewport, not of the
       // vertices in the viewport
       double getMinViewCoord() { return m_xMin; };
@@ -157,6 +172,7 @@ class TextureWidget : public QGLWidget
 
    signals:
       void updateCoordinatesSignal();
+      void updateSelectionDoneSignal();
       void updateCoordinatesDoneSignal();
       void updateRangeSignal();
       void updateRangeDoneSignal();
@@ -165,11 +181,15 @@ class TextureWidget : public QGLWidget
       void zoomLevelChanged( QString zoomStr );
 
    protected:
-      virtual void mousePressEvent( QMouseEvent * e );
-      virtual void mouseReleaseEvent( QMouseEvent * e );
-      virtual void mouseMoveEvent( QMouseEvent * e );
-      virtual void wheelEvent( QWheelEvent * e );
-      virtual void keyPressEvent( QKeyEvent * e );
+#if QT_VERSION < QT_VERSION_CHECK( 5, 6, 0 )
+      qreal devicePixelRatioF() { return devicePixelRatio(); }
+#endif
+
+      void mousePressEvent( QMouseEvent * e ) override;
+      void mouseReleaseEvent( QMouseEvent * e ) override;
+      void mouseMoveEvent( QMouseEvent * e ) override;
+      void wheelEvent( QWheelEvent * e ) override;
+      void keyPressEvent( QKeyEvent * e ) override;
 
       void moveSelectedVertices( double x, double y );
       void updateSelectRegion( double x, double y );
@@ -198,9 +218,9 @@ class TextureWidget : public QGLWidget
             bool & all, bool & top, bool & bottom, bool & left, bool & right );
       void setDragCursor( bool all, bool top, bool bottom, bool left, bool right );
 
-      void initializeGL();
-      void paintGL();
-      void resizeGL( int w, int h );
+      void initializeGL() override;
+      void paintGL() override;
+      void resizeGL( int w, int h ) override;
 
       void paintInternal();
 
@@ -211,6 +231,11 @@ class TextureWidget : public QGLWidget
       double distance( const double &, const double &, const double &, const double & );
       double max( const double &, const double & );
 
+      double adjustToNearest( double angle );
+
+      void useLinesColor();
+      void useSelectionColor();
+
       int m_viewportWidth;
       int m_viewportHeight;
 
@@ -241,6 +266,7 @@ class TextureWidget : public QGLWidget
 
       DrawModeE       m_drawMode;
       bool            m_drawVertices;
+      bool            m_drawBorder;
       bool            m_solidBackground;
       MouseOperationE m_operation;
 
@@ -263,6 +289,10 @@ class TextureWidget : public QGLWidget
       double m_yMin;
       double m_yMax;
 
+      // For move and scale
+      bool   m_allowX;
+      bool   m_allowY;
+
       // For select
       double m_xSel1;
       double m_ySel1;
@@ -306,6 +336,9 @@ class TextureWidget : public QGLWidget
       double m_startLengthX;
       double m_startLengthY;
 
+      uint32_t m_linesColor;
+      uint32_t m_selectionColor;
+
       ScaleVerticesList m_scaleList;
 };
 
