@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -25,16 +25,16 @@
 
 #include "version.h"
 
-#include <QtGui/QTextBrowser>
+#include <QtWidgets/QTextBrowser>
 
-#define ABOUT_TEXT "<html><head><title>Misfit Model 3D - About</title></head> " \
+#define ABOUT_TEXT "<html><head><title>Maverick Model 3D - About</title></head> " \
    "<body><center><br>" \
-   "<h1>Misfit Model 3D</h1>" \
-   "<h2>" VERSION_STRING "</h2> <br>" \
-   "http://www.misfitcode.com/misfitmodel3d/<br><br>" \
-   "Copyright &copy; 2004-2007, Kevin Worcester<br>" \
-   "<font color=\"blue\">kevin&nbsp;at</font>&nbsp;the&nbsp;<font color=\"blue\">misfitcode.com</font> domain<br>" \
-   "</center></body></html>" 
+   "<h1>Maverick Model 3D</h1>" \
+   "<h2>" VERSION_STRING "</h2><br>" \
+   "https://clover.moe/mm3d<br><br>" \
+   "Copyright &copy; 2004-2008, Kevin Worcester<br>" \
+   "Copyright &copy; 2009-2019 Zack Middleton<br><br>" \
+   "</center></body></html>"
 
 AboutWin::AboutWin( QWidget * parent )
    : QDialog( parent )
@@ -43,7 +43,7 @@ AboutWin::AboutWin( QWidget * parent )
    setupUi( this );
 
    setModal( false );
-   setWindowTitle( tr( "Misfit Model 3D - About") );
+   setWindowTitle( tr( "Maverick Model 3D - About") );
 
    resize( 350, 300 );
    m_text->setHtml( QString( ABOUT_TEXT ) );
