@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -36,16 +36,16 @@
 
 #include <unistd.h>
 
-#include <QtGui/QFileDialog>
-#include <QtGui/QPushButton>
-#include <QtGui/QLabel>
-#include <QtGui/QShortcut>
-#include <QtGui/QSpinBox>
-#include <QtGui/QLineEdit>
-#include <QtGui/QRadioButton>
-#include <QtGui/QComboBox>
+#include <QtWidgets/QFileDialog>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QShortcut>
+#include <QtWidgets/QSpinBox>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QComboBox>
 #include <QtGui/QImage>
-#include <QtGui/QShortcut>
+#include <QtWidgets/QShortcut>
 
 AnimExportWindow::AnimExportWindow( Model * model, ViewPanel * viewPanel, QWidget * parent )
    : QDialog( parent ),
@@ -150,13 +150,12 @@ AnimExportWindow::AnimExportWindow( Model * model, ViewPanel * viewPanel, QWidge
 
    if ( path.isNull() || path.isEmpty() )
    {
-      char cwd[ PATH_MAX ] = "/";
-//#ifdef WIN32
-//      _getcwd( cwd, sizeof( cwd ) );
-//#else
-      getcwd( cwd, sizeof( cwd ) );
-//#endif
-      path = cwd;
+      char * cwd = PORT_get_current_dir_name();
+      if ( cwd )
+      {
+         path = cwd;
+         free( cwd );
+      }
    }
 
    m_directoryLabel->setText( path );
@@ -218,6 +217,12 @@ void AnimExportWindow::accept()
       return;
    }
 
+   if ( !v->m_modelView->isValid() )
+   {
+      // invalid opengl context
+      return;
+   }
+
    Model::AnimationModeE mode = Model::ANIMMODE_SKELETAL;
    unsigned a = m_animValue->currentIndex();
    if ( a >= m_model->getAnimCount( mode ) )
@@ -231,7 +236,7 @@ void AnimExportWindow::accept()
    double duration = 0.0;
    double tm = 0.0;
 
-   double outfps = atof( m_frameRateValue->text().toUtf8() );
+   double outfps = m_frameRateValue->text().toDouble();
    if ( outfps < 0.0001 )
    {
       msg_warning( (const char *) tr("Must have more than 0 frames per second").toUtf8() );
@@ -241,12 +246,12 @@ void AnimExportWindow::accept()
 
    if ( m_timeButton->isChecked() )
    {
-      duration = atof( m_secondsValue->text().toUtf8() );
+      duration = m_secondsValue->text().toDouble();
    }
    else
    {
       duration = spf 
-         * atoi( m_iterationsValue->text().toUtf8() ) 
+         * m_iterationsValue->text().toInt()
          * m_model->getAnimFrameCount( mode, a );
    }
 
@@ -262,13 +267,12 @@ void AnimExportWindow::accept()
    {
       g_prefs( "ui_animexport_dir" ) = (const char *) path.toUtf8();
       g_prefs( "ui_animexport_format" ) = m_formatValue->currentIndex();
-      g_prefs( "ui_animexport_framerate" ) = atof( m_frameRateValue->text().toUtf8() );
-      g_prefs( "ui_animexport_seconds" ) = atoi( m_secondsValue->text().toUtf8() );
-      g_prefs( "ui_animexport_iterations" ) = atoi( m_iterationsValue->text().toUtf8() );
+      g_prefs( "ui_animexport_framerate" ) = m_frameRateValue->text().toDouble();
+      g_prefs( "ui_animexport_seconds" ) = m_secondsValue->text().toInt();
+      g_prefs( "ui_animexport_iterations" ) = m_iterationsValue->text().toInt();
 
       bool enable = m_model->setUndoEnabled( false );
 
-      m_model->setAnimationLooping( true );
       m_model->setCurrentAnimation( mode, a );
 
       int frameNum = 0;
