@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -30,7 +30,7 @@
 
 #include "model.h"
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 class QTimer;
 
@@ -84,7 +84,6 @@ class AnimWidget : public QWidget, public Ui::AnimWidgetBase
       void insertAnimationNames();
 
       Model  * m_model;
-      bool     m_doLoop;
       bool     m_playing;
       double   m_timeInterval;
       double   m_currentTime;
