@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2008 Kevin Worcester
  * 
@@ -24,7 +24,7 @@
 #ifndef ANIMWIN_H_INC__
 #define ANIMWIN_H_INC__
 
-#include <QtGui/QDockWidget>
+#include <QtWidgets/QDockWidget>
 
 #include "animwidget.h"
 
