@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -27,7 +27,7 @@
 
 #include "log.h"
 
-#include <QtGui/QLayout>
+#include <QtWidgets/QLayout>
 #include <QtGui/QContextMenuEvent>
 
 BoolPanel::BoolPanel( Model * model, QWidget * parent, ViewPanel * panel )
