@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -27,7 +27,7 @@
 #include "contextwidget.h"
 #include "model.h"
 
-#include <QtGui/QDockWidget>
+#include <QtWidgets/QDockWidget>
 
 class QContextMenuEvent;
 
