@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -27,8 +27,8 @@
 
 #include "helpwin.h"
 
-#include <QtGui/QRadioButton>
-#include <QtGui/QShortcut>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QShortcut>
 
 Cal3dPrompt::Cal3dPrompt()
    : QDialog( NULL )
