@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -30,7 +30,7 @@ class ContextPanelObserver;
 
 #include "contextwidget.h"
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 class Model;
 
