@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -24,7 +24,7 @@
 
 #include "model.h"
 
-#include <QtGui/QLineEdit>
+#include <QtWidgets/QLineEdit>
 
 #include <stdlib.h>
 
@@ -69,19 +69,31 @@ void ContextRotation::modelChanged( int changeBits )
          }
       }
 
-      if ( m_model->getAnimationMode() == Model::ANIMMODE_SKELETAL )
+      Model::AnimationModeE animationMode = m_model->getAnimationMode();
+      if ( animationMode == Model::ANIMMODE_NONE
+            || animationMode == Model::ANIMMODE_SKELETAL )
       {
          unsigned int bcount = m_model->getBoneJointCount();
          for ( unsigned int b = 0; searching && b < bcount; b++ )
          {
             if ( m_model->isBoneJointSelected(b) )
             {
-               int anim = m_model->getCurrentAnimation();
-               int frame = m_model->getCurrentAnimationFrame();
-               if ( m_model->getSkelAnimKeyframe( anim, frame, b, true,
-                        rad[0], rad[1], rad[2] ) )
+               if ( animationMode == Model::ANIMMODE_SKELETAL )
+               {
+                  int anim = m_model->getCurrentAnimation();
+                  int frame = m_model->getCurrentAnimationFrame();
+                  if ( m_model->getSkelAnimKeyframe( anim, frame, b, true,
+                           rad[0], rad[1], rad[2] ) )
+                  {
+                     searching = false;
+                  }
+               }
+               else
                {
                   searching = false;
+                  Matrix rm;
+                  m_model->getBoneJointRelativeMatrix( b, rm );
+                  rm.getRotation( rad[0], rad[1], rad[2] );
                }
             }
          }
@@ -94,13 +106,13 @@ void ContextRotation::modelChanged( int changeBits )
 
       QString str;
 
-      str.sprintf( "%f", rad[0] );
+      str.sprintf( "%f", (float)rad[0] );
       m_xValue->setText( str );
 
-      str.sprintf( "%f", rad[1] );
+      str.sprintf( "%f", (float)rad[1] );
       m_yValue->setText( str );
 
-      str.sprintf( "%f", rad[2] );
+      str.sprintf( "%f", (float)rad[2] );
       m_zValue->setText( str );
 
       this->setEnabled( searching ? false : true );
@@ -117,9 +129,9 @@ void ContextRotation::updateRotation()
 
       // Change model based on text field input
       double rad[3];
-      rad[0] = atof( m_xValue->text().toLatin1() );
-      rad[1] = atof( m_yValue->text().toLatin1() );
-      rad[2] = atof( m_zValue->text().toLatin1() );
+      rad[0] = m_xValue->text().toDouble();
+      rad[1] = m_yValue->text().toDouble();
+      rad[2] = m_zValue->text().toDouble();
 
       rad[0] = rad[0] * PIOVER180;
       rad[1] = rad[1] * PIOVER180;
@@ -137,20 +149,28 @@ void ContextRotation::updateRotation()
          }
       }
 
-      if ( m_model->getAnimationMode() == Model::ANIMMODE_SKELETAL )
+      Model::AnimationModeE animationMode = m_model->getAnimationMode();
+      if ( animationMode == Model::ANIMMODE_NONE
+            || animationMode == Model::ANIMMODE_SKELETAL )
       {
          unsigned int bcount = m_model->getBoneJointCount();
          for ( unsigned int b = 0; searching && b < bcount; b++ )
          {
             if ( m_model->isBoneJointSelected(b) )
             {
-               int anim = m_model->getCurrentAnimation();
-               int frame = m_model->getCurrentAnimationFrame();
-               if ( m_model->setSkelAnimKeyframe( anim, frame, b, true,
-                        rad[0], rad[1], rad[2] ) )
+               if ( animationMode == Model::ANIMMODE_SKELETAL )
+               {
+                  int anim = m_model->getCurrentAnimation();
+                  int frame = m_model->getCurrentAnimationFrame();
+                  searching = false;
+                  m_model->setSkelAnimKeyframe( anim, frame, b, true, rad[0], rad[1], rad[2] );
+                  m_model->setCurrentAnimationFrame( frame ); // Force re-animate
+               }
+               else
                {
                   searching = false;
-                  m_model->setCurrentAnimationFrame( frame ); // Force re-animate
+                  m_model->setBoneJointRotation( b, rad );
+                  m_model->setupJoints();
                }
             }
          }
