@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -28,9 +28,9 @@
 
 #include "helpwin.h"
 
-#include <QtGui/QRadioButton>
-#include <QtGui/QLineEdit>
-#include <QtGui/QShortcut>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QShortcut>
 
 Ms3dPrompt::Ms3dPrompt()
    : QDialog( NULL )
@@ -60,11 +60,17 @@ void Ms3dPrompt::setOptions( Ms3dFilter::Ms3dOptions * opts )
       case 2:
          m_subVersion2->setChecked( true );
          break;
+      case 3:
+         m_subVersion3->setChecked( true );
+         break;
    }
    char str[20];
    PORT_snprintf( str, sizeof(str), "%X", opts->m_vertexExtra );
    m_vertexExtra->setText( str );
 
+   PORT_snprintf( str, sizeof(str), "%X", opts->m_vertexExtra2 );
+   m_vertexExtra2->setText( str );
+
    // TODO joint color
    //PORT_snprintf( str, sizeof(str), "%X", opts->m_jointColor );
    //m_jointColor->setText( str );
@@ -79,11 +85,17 @@ void Ms3dPrompt::getOptions( Ms3dFilter::Ms3dOptions * opts )
       opts->m_subVersion = 1;
    if ( m_subVersion2->isChecked() )
       opts->m_subVersion = 2;
+   if ( m_subVersion3->isChecked() )
+      opts->m_subVersion = 3;
 
    uint32_t val = 0xffffffff;
    sscanf( m_vertexExtra->text().toUtf8(), "%X", &val);
    opts->m_vertexExtra   = val;
 
+   val = 0xffffffff;
+   sscanf( m_vertexExtra2->text().toUtf8(), "%X", &val);
+   opts->m_vertexExtra2   = val;
+
    // TODO joint color
    //val = 0xffffffff;
    //sscanf( m_jointColor->text().toUtf8(), "%X", &val);
@@ -103,9 +115,17 @@ void Ms3dPrompt::subVersionChangedEvent()
 
 void Ms3dPrompt::updateExtraEnabled()
 {
-   m_vertexExtra->setEnabled( m_subVersion2->isChecked() );
+   int subVersion = 0;
+   if ( m_subVersion1->isChecked() )
+      subVersion = 1;
+   if ( m_subVersion2->isChecked() )
+      subVersion = 2;
+   if ( m_subVersion3->isChecked() )
+      subVersion = 3;
+   m_vertexExtra->setEnabled( subVersion >= 2 );
+   m_vertexExtra2->setEnabled( subVersion >= 3 );
    // TODO joint color
-   //m_jointColor->setEnabled( !m_subVersion0->isChecked() );
+   //m_jointColor->setEnabled( !m_jointSubVersion0->isChecked() );
 }
 
 // This function takes a ModelFilter::Options argument, downcasts it
