@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -27,7 +27,7 @@
 #include "modelview.base.h"
 #include "modelviewport.h"
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 class Model;
 class Toolbox;
@@ -63,12 +63,6 @@ class ModelView : public QWidget, public Ui::ModelViewBase
       void zoomInEvent();
       void zoomOutEvent();
 
-      void wireframeEvent();
-      void flatEvent();
-      void smoothEvent();
-      void textureEvent();
-      void alphaEvent();
-
    protected:
 
       Toolbox * m_toolbox;
