@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -38,9 +38,9 @@ class PaintWidget : public QGLWidget
       virtual ~PaintWidget();
 
    protected:
-      void initializeGL();
-      void paintGL();
-      void resizeGL( int w, int h );
+      void initializeGL() override;
+      void paintGL() override;
+      void resizeGL( int w, int h ) override;
 
       TextureWidget * m_drawBuddy;
 };
