@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -28,12 +28,12 @@
 #include "texwidget.h"
 #include "decalmgr.h"
 
-#include <QtGui/QInputDialog>
-#include <QtGui/QPushButton>
-#include <QtGui/QComboBox>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QShortcut>
+#include <QtWidgets/QInputDialog>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QShortcut>
 
 #include <list>
 
@@ -431,7 +431,7 @@ void ProjectionWin::projectionIndexChangedEvent( int newIndex )
 
 void ProjectionWin::zoomChangeEvent()
 {
-   double zoom = atof( m_zoomInput->text().toLatin1() );
+   double zoom = m_zoomInput->text().toDouble();
    if ( zoom < 0.00001 )
    {
       zoom = 1;
