@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -28,6 +28,8 @@
 #include "log.h"
 
 #include <ctype.h>
+#include <stdlib.h>
+#include <cstdio>
 
 #include <QtCore/QBuffer>
 #include <QtCore/QString>
@@ -231,7 +233,7 @@ Texture::ErrorE QtTextureFilter::writeFile( Texture * texture, const char * file
       }
    }
 
-   delete data; // Must do this after image goes out of scope
+   delete[] data; // Must do this after image goes out of scope
 
    return err;
 }
@@ -275,7 +277,7 @@ Texture::ErrorE QtTextureFilter::writeMemory( const char * format, Texture * tex
       memcpy( (*d)->getDataPtr(), ba.data(), ba.size() );
    }
 
-   delete data; // Must do this after image goes out of scope
+   delete[] data; // Must do this after image goes out of scope
 
    return err;
 }
@@ -316,7 +318,7 @@ list<string> QtTextureFilter::getWriteTypes()
 
 void QtTextureFilter::getFormatString( char * format, const char * filename )
 {
-   char * ext = strrchr( filename, '.' );
+   const char * ext = strrchr( filename, '.' );
    if ( ext )
    {
       ext++; // Skip '.'
@@ -381,6 +383,24 @@ void QtTextureFilter::imageToTexture( Texture * texture, QImage * image )
    bool hasAlpha = image->hasAlphaChannel();
    log_debug( "Alpha channel: %s\n", hasAlpha ? "present" : "not present" );
 
+   // Ignore opaque alpha channel
+   if ( hasAlpha )
+   {
+      hasAlpha = false;
+
+      for ( int y = 0; y < texture->m_height && hasAlpha == false; y ++ )
+      {
+         for ( int x = 0; x < texture->m_width && hasAlpha == false; x++ )
+         {
+            QRgb p = image->pixel( x, texture->m_height - y - 1 );
+            if ( qAlpha( p ) < 255 )
+            {
+               hasAlpha = true;
+            }
+         }
+      }
+   }
+
    unsigned pixelBytes = hasAlpha ? 4 : 3;
    unsigned pixelCount = texture->m_width * texture->m_height;
    unsigned imageSize = pixelCount * (pixelBytes * sizeof(uint8_t));
