@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -22,7 +22,7 @@
 
 #include "transimp.h"
 
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 #include "translate.h"
 
 std::string _qt_translate( const char * str )
