@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -24,8 +24,8 @@
 #ifndef __VIEWPANEL_H
 #define __VIEWPANEL_H
 
-#include <QtGui/QWidget>
-#include <QtGui/QGridLayout>
+#include <QtWidgets/QWidget>
+#include <QtWidgets/QGridLayout>
 
 #include "modelviewport.h"
 
