@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -62,7 +62,28 @@ class QContextMenuEvent;
 class QCloseEvent;
 class QResizeEvent;
 
-#include <QtGui/QMainWindow>
+#include <QtWidgets/QMainWindow>
+#include <QtCore/QObject>
+
+class CommandWidget : public QObject
+{
+   Q_OBJECT
+
+   public:
+      CommandWidget( QObject * parent, Model * model, bool * canEdit,
+            Command * cmd, int index );
+      virtual ~CommandWidget();
+
+   public slots:
+      void setModel( Model * m );
+      void activateCommand( bool );
+
+   private:
+      Model * m_model;
+      bool * m_canEdit;
+      Command * m_cmd;
+      int m_index;
+};
 
 class ViewWindow : public QMainWindow, public ContextPanelObserver
 {
@@ -73,6 +94,7 @@ class ViewWindow : public QMainWindow, public ContextPanelObserver
       virtual ~ViewWindow();
 
       static bool closeAllWindows();
+      static bool openModelInEmptyWindow( const char * filename );
 
       static bool openModel( const char * filename );
       static bool openModelDialog( const char * openDirectory = NULL );
@@ -84,6 +106,8 @@ class ViewWindow : public QMainWindow, public ContextPanelObserver
       bool openModelInWindow( const char * filename );
       bool openModelDialogInWindow( const char * openDirectory = NULL );
 
+      bool emptyWindow();
+
       bool getSaved();
       bool getAbortQuit() { return m_abortQuit; };
       void setAbortQuit( bool o ) { m_abortQuit = o; };
@@ -130,6 +154,7 @@ class ViewWindow : public QMainWindow, public ContextPanelObserver
 
       void groupWindowEvent();
       void textureWindowEvent();
+      void groupCleanWindowEvent();
       void textureCoordEvent();
       void paintTextureEvent();
       void projectionWindowEvent();
@@ -141,7 +166,6 @@ class ViewWindow : public QMainWindow, public ContextPanelObserver
       void buttonToggled( bool on );
 
       void toolActivated( QAction * id );
-      void primitiveCommandActivated( QAction * id );
       void scriptActivated( QAction * id );
 
       void animSetWindowEvent();
@@ -235,6 +259,7 @@ class ViewWindow : public QMainWindow, public ContextPanelObserver
       {
          QAction * id;
          Command * command;
+         CommandWidget * widget;
          int arg;
       } CommandMenuItemT;
 
