@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -90,7 +90,7 @@ static void _setMaterial( DrawingContext * context, int texture, Model::Material
    if ( material->m_type == Model::Material::MATTYPE_TEXTURE )
    {
       glBindTexture( GL_TEXTURE_2D,
-            context->m_textures[ context->m_currentTexture ] );
+            context->m_matTextures[ context->m_currentTexture ] );
 
       glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, 
             material->m_sClamp ? GL_CLAMP : GL_REPEAT);
@@ -200,11 +200,15 @@ void BspTree::Poly::render( DrawingContext * context )
       glBegin( GL_TRIANGLES );
    }
 
-   for ( int i = 0; i < 3; i++ )
+   Model::Triangle * tri = static_cast< Model::Triangle *>( triangle );
+   if ( tri->m_visible )
    {
-      glTexCoord2f( s[ i ], t[ i ] );
-      glNormal3fv( drawNormals[i] );
-      glVertex3fv( coord[i] );
+      for ( int i = 0; i < 3; i++ )
+      {
+         glTexCoord2f( s[ i ], t[ i ] );
+         glNormal3fv( drawNormals[i] );
+         glVertex3fv( coord[i] );
+      }
    }
 }
 
@@ -335,6 +339,7 @@ void BspTree::Node::splitNodes( int idx1, int idx2, int idx3,
 
    n1->self->calculateNormal();
    n1->self->texture = self->texture;
+   n1->self->triangle = self->triangle;
    n1->self->material = self->material;
 
    n2->self = Poly::get();
@@ -359,6 +364,7 @@ void BspTree::Node::splitNodes( int idx1, int idx2, int idx3,
 
    n2->self->calculateNormal();
    n2->self->texture = self->texture;
+   n2->self->triangle = self->triangle;
    n2->self->material = self->material;
 
    for ( int i = 0; i < 3; i++ )
@@ -405,6 +411,7 @@ void BspTree::Node::splitNode( int idx1, int idx2, int idx3,
 
    n1->self->calculateNormal();
    n1->self->texture = self->texture;
+   n1->self->triangle = self->triangle;
    n1->self->material = self->material;
 
    for ( int i = 0; i < 3; i++ )
