@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -39,6 +39,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <limits.h>
 #include <errno.h>
 #include <vector>
@@ -49,7 +50,7 @@ using std::string;
 const char     MisfitFilterRef::MAGIC[] = "MISFIT3D";
 
 const uint8_t  MisfitFilterRef::WRITE_VERSION_MAJOR = 0x01;
-const uint8_t  MisfitFilterRef::WRITE_VERSION_MINOR = 0x05;  // FIXME bump version
+const uint8_t  MisfitFilterRef::WRITE_VERSION_MINOR = 0x07;
 
 const uint16_t MisfitFilterRef::OFFSET_TYPE_MASK  = 0x3fff;
 const uint16_t MisfitFilterRef::OFFSET_UNI_MASK   = 0x8000;
@@ -346,6 +347,16 @@ typedef enum _MisfitFlags_e
    MF_MAT_CLAMP_T = 32
 } MisfitFlagsE;
 
+typedef enum _MisfitFrameAnimFlags_e
+{
+   MFAF_ANIM_LOOP = 0x0001
+} MisfitFrameAnimFlagsE;
+
+typedef enum _MisfitSkelAnimFlags_e
+{
+   MSAF_ANIM_LOOP = 0x0001
+} MisfitSkelAnimFlagsE;
+
 static const uint16_t _misfitOffsetTypes[MDT_MAX]  = {
 
    // Offset A types
@@ -707,6 +718,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
    for ( t = 0; t < offsetCount; t++ )
    {
       MisfitOffsetT mo;
+      memset(&mo, 0, sizeof(mo));
       read( mo.offsetType );
       read( mo.offsetValue );
 
@@ -853,6 +865,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          }
 
          MM3DFILE_VertexT fileVert;
+         memset(&fileVert, 0, sizeof(fileVert));
 
          read( fileVert.flags );
          read( fileVert.coord[0] );
@@ -903,6 +916,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          }
 
          MM3DFILE_TriangleT fileTri;
+         memset(&fileTri, 0, sizeof(fileTri));
          read( fileTri.flags );
          read( fileTri.vertex[0] );
          read( fileTri.vertex[1] );
@@ -1007,10 +1021,10 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
 
          Model::Group    * grp = Model::Group::get();
 
-         uint16_t flags;
-         uint32_t triCount;
-         uint8_t  smoothness;
-         uint32_t materialIndex;
+         uint16_t flags = 0;
+         uint32_t triCount = 0;
+         uint8_t  smoothness = 0;
+         uint32_t materialIndex = 0;
          char name[1024];
 
          read( flags );
@@ -1237,6 +1251,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          }
 
          MM3DFILE_TexCoordT tc;
+         memset(&tc, 0, sizeof(tc));
          read( tc.flags );
          read( tc.triangleIndex );
          read( tc.sCoord[0] );
@@ -1288,6 +1303,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          }
 
          MM3DFILE_CanvasBackgroundT cb;
+         memset(&cb, 0, sizeof(cb));
          read( cb.flags );
          read( cb.viewIndex );
          read( cb.scale );
@@ -1526,6 +1542,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          }
 
          MM3DFILE_SmoothAngleT fileSa;
+         memset(&fileSa, 0, sizeof(fileSa));
          read( fileSa.groupIndex );
          read( fileSa.angle );
 
@@ -1582,6 +1599,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          }
 
          MM3DFILE_WeightedInfluenceT fileWi;
+         memset(&fileWi, 0, sizeof(fileWi));
          read( fileWi.posType );
          read( fileWi.posIndex );
          read( fileWi.infIndex );
@@ -1783,10 +1801,10 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
             read( size );
          }
 
-         uint16_t  flags;
-         char      name[1024];
-         float32_t fps;
-         uint32_t  frameCount;
+         uint16_t  flags = 0;
+         char      name[1024] = "";
+         float32_t fps = 0.0f;
+         uint32_t  frameCount = 0;
 
          read( flags );
 
@@ -1804,15 +1822,17 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          unsigned anim = model->addAnimation( Model::ANIMMODE_SKELETAL, name );
          model->setAnimFPS( Model::ANIMMODE_SKELETAL, anim, fps );
          model->setAnimFrameCount( Model::ANIMMODE_SKELETAL, anim, frameCount );
+         model->setAnimLooping( Model::ANIMMODE_SKELETAL, anim, (flags & MSAF_ANIM_LOOP) != 0 );
 
          for ( unsigned f = 0; f < frameCount; f++ )
          {
-            uint32_t keyframeCount;
+            uint32_t keyframeCount = 0;
             read( keyframeCount );
 
             for ( unsigned k = 0; k < keyframeCount; k++ )
             {
                MM3DFILE_SkelKeyframeT fileKf;
+               memset(&fileKf, 0, sizeof(fileKf));
                read( fileKf.jointIndex );
                read( fileKf.keyframeType );
                read( fileKf.param[0] );
@@ -1863,10 +1883,10 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
             return Model::ERROR_BAD_DATA;
          }
 
-         uint16_t  flags;
-         char      name[1024];
-         float32_t fps;
-         uint32_t  frameCount;
+         uint16_t  flags = 0;
+         char      name[1024] = "";
+         float32_t fps = 0.0f;
+         uint32_t  frameCount = 0;
 
          read( flags );
 
@@ -1895,6 +1915,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          unsigned anim = model->addAnimation( Model::ANIMMODE_FRAME, name );
          model->setAnimFPS( Model::ANIMMODE_FRAME, anim, fps );
          model->setAnimFrameCount( Model::ANIMMODE_FRAME, anim, frameCount );
+         model->setAnimLooping( Model::ANIMMODE_FRAME, anim, (flags & MFAF_ANIM_LOOP) != 0 );
 
          for ( unsigned f = 0; f < frameCount; f++ )
          {
@@ -1948,9 +1969,9 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
             read( size );
          }
 
-         uint16_t  flags;
-         uint32_t  anim;
-         uint32_t  frameCount;
+         uint16_t  flags = 0;
+         uint32_t  anim = 0;
+         uint32_t  frameCount = 0;
 
          read( flags );
 
@@ -2057,9 +2078,9 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          if ( modelJoints[j]->m_parent >= (signed) jcount )
          {
             log_warning( "Joint %d has bad parent joint, checking endianness\n", j );
-            if ( htonl( modelJoints[j]->m_parent ) < jcount )
+            if ( htob_u32( modelJoints[j]->m_parent ) < jcount )
             {
-               modelJoints[j]->m_parent = htonl( modelJoints[j]->m_parent );
+               modelJoints[j]->m_parent = htob_u32( modelJoints[j]->m_parent );
             }
             else if ( htol_u32( modelJoints[j]->m_parent ) < jcount )
             {
