@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -21,15 +21,17 @@
  */
 
 #include "mm3dport.h"
+#include "misc.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
 #include <ctype.h>
 #include <string.h>
 #include <limits.h>
+#include <errno.h>
+#include <string>
 
 #include "config.h"
-#include "log.h" // FIXME debugging
 
 #ifdef HAVE_GETTIMEOFDAY
 #include <sys/time.h>
@@ -39,22 +41,102 @@
 
 #include <unistd.h>
 
-char * PORT_getenv( const char * name )
-{
 #ifdef WIN32
-   return "C:/";  // TODO do registry lookup (if it's ever needed)
-#else
-   return getenv( name );
-#endif // WIN32
-}
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
 
-int PORT_lstat( const char * filename, struct stat * buf )
+// FIXME: This requires Windows Vista.
+#ifndef WC_ERR_INVALID_CHARS
+#define WC_ERR_INVALID_CHARS 0x80
+#endif
+#endif
+
+// TODO: Cache this instead of mallocing each time but still have some way to free it at shutdown.
+char * PORT_get_current_dir_name( void )
 {
 #ifdef WIN32
-   return stat( filename, buf );
+	DWORD length = GetCurrentDirectoryW( 0, NULL );
+	if ( length == 0 )
+	{
+		return NULL;
+	}
+
+	wchar_t *wbuf = (wchar_t *)malloc( length * sizeof( wchar_t ) );
+	if ( !wbuf )
+	{
+		return NULL;
+	}
+
+	if ( GetCurrentDirectoryW( length, wbuf ) == 0 )
+	{
+		free( wbuf );
+		return NULL;
+	}
+
+	DWORD utf8Size = WideCharToMultiByte( CP_UTF8, WC_ERR_INVALID_CHARS, wbuf, length, NULL, 0, NULL, NULL );
+
+	char * buf = (char *)malloc( utf8Size );
+	if ( !buf )
+	{
+		free( wbuf );
+		return NULL;
+	}
+
+	if ( WideCharToMultiByte( CP_UTF8, WC_ERR_INVALID_CHARS, wbuf, length, buf, utf8Size, NULL, NULL ) == 0 )
+	{
+		free( wbuf );
+		free( buf );
+		return NULL;
+	}
+
+	return buf;
 #else
-   return lstat( filename, buf );
-#endif // WIN32
+	// malloc'ing buffer when passed NULL is a non-standard extension to POSIX.
+	// It's supported by glibc, FreeBSD, and probably others.
+	char * buf = getcwd( NULL, 0 );
+	if ( buf )
+	{
+		return buf;
+	}
+
+	size_t size = 64;
+	buf = (char*)malloc( size );
+	while ( buf )
+	{
+		if ( getcwd( buf, size ) )
+		{
+			break;
+		}
+		else
+		{
+			if ( errno == ERANGE )
+			{
+				if ( size >= 1024 )
+					size = size + 1024;
+				else
+					size = size + size;
+
+				char * newbuf = (char*)realloc( buf, size );
+				if ( newbuf )
+				{
+					buf = newbuf;
+				}
+				else
+				{
+					free( buf );
+					buf = NULL;
+				}
+			}
+			else
+			{
+				// unhandled error
+				free( buf );
+				buf = NULL;
+			}
+		}
+	}
+	return buf;
+#endif
 }
 
 // FIXME add thorough testing for the manual part of this (the case where
@@ -62,7 +144,25 @@ int PORT_lstat( const char * filename, struct stat * buf )
 char * PORT_realpath( const char * path, char * resolved_path, size_t len )
 {
 #ifdef WIN32
-   char * rval = _fullpath( resolved_path, path, len );
+   char * rval = NULL;
+   std::wstring widePath = utf8PathToWide( path );
+   if ( !widePath.empty() )
+   {
+      DWORD requiredSize = GetFullPathNameW( &widePath[0], 0, NULL, NULL );
+      std::wstring realpath( requiredSize, '\0' );
+      if ( GetFullPathNameW( &widePath[0], requiredSize, &realpath[0], NULL ) != 0 )
+      {
+         if ( WideCharToMultiByte( CP_UTF8, WC_ERR_INVALID_CHARS, &realpath[0], -1, resolved_path, len, NULL, NULL ) != 0 ) {
+            // \\?\ is added by utf8PathToWide() for Windows API but don't return it.
+            if ( strncmp( resolved_path, "\\\\?\\", 4 ) == 0 )
+            {
+               memmove( &resolved_path[0], &resolved_path[4], strlen( &resolved_path[4] ) + 1 );
+            }
+
+            rval = resolved_path;
+         }
+      }
+   }
 #else
    char * rval = realpath( path, resolved_path );
 #endif // WIN32
@@ -70,19 +170,28 @@ char * PORT_realpath( const char * path, char * resolved_path, size_t len )
    {
       if ( len > 0 )
       {
-         if ( path[0] == '/' )
+         if ( pathIsAbsolute( path ) )
          {
             strncpy( resolved_path, path, len );
          }
          else
          {
-            char pwd[1024];
-            getcwd(pwd, sizeof(pwd));
-            PORT_snprintf( resolved_path, len, "%s/%s", pwd, path );
+            char *pwd = PORT_get_current_dir_name();
+            if ( pwd )
+            {
+               PORT_snprintf( resolved_path, len, "%s/%s", pwd, path );
+               free( pwd );
+            }
+            else
+            {
+               PORT_snprintf( resolved_path, len, "./%s", path );
+            }
          }
          resolved_path[ len - 1 ] = '\0';
          rval = resolved_path;
 
+         replaceBackslash( resolved_path );
+
          // Remove "/./" and "//"
          char * end = rval + strlen(rval);
 
@@ -128,8 +237,6 @@ char * PORT_realpath( const char * path, char * resolved_path, size_t len )
                return rval;
             }
          }
-
-         //log_warning( "normalized path = '%s'\n", rval );
       }
    }
    return rval;
@@ -183,7 +290,21 @@ int PORT_symlink( const char * oldpath, const char * newpath )
 int PORT_mkdir( const char * pathname, mode_t mode )
 {
 #ifdef WIN32
-   return mkdir( pathname );
+   std::wstring widePath = utf8PathToWide( pathname );
+   if ( widePath.empty() )
+   {
+      errno = EINVAL;
+      return -1;
+   }
+
+   if ( CreateDirectoryW( &widePath[0], NULL ) )
+      return 0;
+
+   if ( GetLastError() == ERROR_ALREADY_EXISTS )
+      return 0;
+
+   errno = ENOENT;
+   return -1;
 #else
    return mkdir( pathname, mode );
 #endif // WIN32
@@ -212,53 +333,12 @@ int PORT_vsnprintf( char * dest, size_t len, const char * fmt, va_list args )
    return rval;
 }
 
-#ifdef WIN32
-char * PORT_strcasestr( const char * haystack, const char * needle )
-{
-   bool match;
-
-   size_t hlen = strlen( haystack );
-   size_t nlen = strlen( needle );
-
-   match = false;
-
-   size_t i;
-   size_t j;
-
-   for ( i = 0; !match && i < hlen - nlen; i++ )
-   {
-      match = true;
-      for ( j = 0; match && j < nlen; j++ )
-      {
-         if ( toupper(haystack[i+j]) != toupper(needle[j]) ) 
-         {
-            match = false;
-         }
-      }
-   }
-
-   if ( match )
-   {
-      return (char *) &haystack[i];
-   }
-   else
-   {
-      return NULL;
-   }
-}
-#else
-char * PORT_strcasestr( const char * haystack, const char * needle )
-{
-   return strcasestr( haystack, needle );
-}
-#endif // WIN32
-
 char * PORT_basename( const char * path )
 {
    static char rval[ PATH_MAX ] = "";
    if ( path )
    {
-      char * start = strrchr( path, '/' );
+      const char * start = strrchr( path, '/' );
 
       if ( !start )
       {
