@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -30,12 +30,6 @@
 #include <stdarg.h>
 #include "config.h"
 
-#ifdef WIN32
-#include <winsock2.h>
-#else
-#include <netinet/in.h>
-#endif // WIN32
-
 
 struct _PORT_timeval
 {
@@ -44,8 +38,7 @@ struct _PORT_timeval
 };
 typedef struct _PORT_timeval PORT_timeval;
 
-char * PORT_getenv( const char * name );
-int    PORT_lstat( const char * filename, struct stat * buf );
+char * PORT_get_current_dir_name( void );
 char * PORT_realpath( const char * path, char * resolved_path, size_t len );
 struct tm * PORT_localtime_r( const time_t * timep, struct tm * result );
 void   PORT_gettimeofday( PORT_timeval * tv );
@@ -54,7 +47,6 @@ int    PORT_symlink( const char * oldpath, const char * newpath );
 int    PORT_mkdir( const char * pathname, mode_t mode );
 int    PORT_snprintf( char * dest, size_t len, const char * fmt, ... );
 int    PORT_vsnprintf( char * dest, size_t len, const char * fmt, va_list args );
-char * PORT_strcasestr( const char * haystack, const char * needle );
 char * PORT_basename( const char * path );
 char * PORT_dirname( const char * path );
 
