@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -1119,6 +1119,16 @@ bool Model::SkelAnim::propEqual(const SkelAnim & rhs, int propBits, double toler
       }
    }
 
+   if ( (propBits & PropLoop) != 0 )
+   {
+      if ( m_loop != rhs.m_loop )
+      {
+         log_warning( "match failed at anim loop, lhs = %d, rhs = %d\n",
+               m_loop, rhs.m_loop );
+         return false;
+      }
+   }
+
    if ( (propBits & PropDimensions) != 0 )
    {
       if ( m_frameCount != rhs.m_frameCount )
@@ -1280,6 +1290,16 @@ bool Model::FrameAnim::propEqual(const FrameAnim & rhs, int propBits, double tol
       }
    }
 
+   if ( (propBits & PropLoop) != 0 )
+   {
+      if ( m_loop != rhs.m_loop )
+      {
+         log_warning( "match failed at anim loop lhs = %d, rhs = %d\n",
+               m_loop, rhs.m_loop );
+         return false;
+      }
+   }
+
    if ( (propBits & (PropCoords | PropRotation)) != 0 )
    {
       if ( m_frameData.size() != rhs.m_frameData.size() )
@@ -1502,7 +1522,7 @@ bool Model::FrameAnimData::propEqual(const FrameAnimData & rhs, int propBits, do
       FrameAnimVertexList::iterator lv = m_frameVertices->begin();
       FrameAnimVertexList::iterator rv = rhs.m_frameVertices->begin();
 
-      for ( ; lv != m_frameVertices->end(), rv != rhs.m_frameVertices->end(); ++lv, ++rv )
+      for ( ; lv != m_frameVertices->end() && rv != rhs.m_frameVertices->end(); ++lv, ++rv )
       {
          if ( !(*lv)->propEqual( **rv, propBits, tolerance ) )
          {
@@ -1515,7 +1535,7 @@ bool Model::FrameAnimData::propEqual(const FrameAnimData & rhs, int propBits, do
       FrameAnimPointList::iterator lp = m_framePoints->begin();
       FrameAnimPointList::iterator rp = rhs.m_framePoints->begin();
 
-      for ( ; lp != m_framePoints->end(), rp != rhs.m_framePoints->end(); ++lp, ++rp )
+      for ( ; lp != m_framePoints->end() && rp != rhs.m_framePoints->end(); ++lp, ++rp )
       {
          if ( !(*lp)->propEqual( **rp, propBits, tolerance ) )
          {
