@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -527,14 +527,14 @@ bool Model::selectTrianglesInVolumeMatrix( bool select, const Matrix & viewMat,
       Triangle * tri = m_triangles[t];
       if ( tri->m_selected != select 
             && tri->m_visible
-            && !test || (test && test->shouldSelect( tri ) )) 
+            && (!test || (test && test->shouldSelect( tri )) )) 
       {
          bool above = false;
          bool below = false;
 
          int v;
          Vertex *vert[3];
-         double tCords[3][3];
+         double tCords[3][4];
 
 
          // 0. Assign vert to triangle's verticies 
@@ -2244,4 +2244,26 @@ void Model::selectFreeVertices()
    endSelectionDifference();
 }
 
+void Model::setSelectedUv( const vector<int> & uvList )
+{
+   m_changeBits |= SelectionChange;
+
+   MU_SetSelectedUv * undo = new MU_SetSelectedUv();
+   undo->setSelectedUv( uvList, m_selectedUv );
+   sendUndo( undo );
+
+   m_selectedUv = uvList;
+}
+
+void Model::getSelectedUv( vector<int> & uvList ) const
+{
+   uvList = m_selectedUv;
+}
+
+void Model::clearSelectedUv()
+{
+   vector<int> empty;
+   setSelectedUv( empty );
+}
+
 #endif // MM3D_EDIT
