@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -38,6 +38,8 @@
 
 #include "mm3dtypes.h"
 
+#include <stdlib.h>
+
 class ModelFilter
 {
    public:
@@ -185,7 +187,9 @@ class ModelFilter
       // openOutput functions.
       void setFactory( FileFactory * factory ) { m_factory = factory; }
 
-      static Model::ModelErrorE errnoToModelError( int err );
+      // Default error should be Model::ERROR_FILE_OPEN, ERROR_FILE_READ, or
+      // ERROR_FILE_WRITE depending on the context of operations being performed.
+      static Model::ModelErrorE errnoToModelError( int err, Model::ModelErrorE defaultError );
 
    protected:
 
@@ -204,12 +208,6 @@ class ModelFilter
       vector<Model::SkelAnim *>           & getSkelList( Model * m )       { return m->m_skelAnims;    };
       vector<Model::FrameAnim *>          & getFrameList( Model * m )      { return m->m_frameAnims;   };
 
-      // These functions are deprecated.  Don't use them.  Really.  They're
-      // probably going to go away when I have some time to clean up the
-      // Milkshape filter.
-      void setModelInitialized( Model * m, bool o ) { m->m_initialized = o; };
-      void setModelNumFrames( Model * m, int numFrames ) { m->m_numFrames = numFrames; };
-
       OptionsFuncF m_optionsFunc;
 
       FileFactory   m_defaultFactory;
