@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -31,9 +31,11 @@
 
 #include <list>
 #include <string>
+#include <vector>
 
 using std::list;
 using std::string;
+using std::vector;
 
 class Model;
 
@@ -185,6 +187,25 @@ class MU_Select : public ModelUndo
       
 };
 
+class MU_SetSelectedUv : public ModelUndo
+{
+   public:
+      MU_SetSelectedUv();
+      virtual ~MU_SetSelectedUv();
+
+      void undo( Model * );
+      void redo( Model * );
+      bool combine( Undo * );
+
+      unsigned size();
+
+      void setSelectedUv( const vector<int> & newUv, const vector<int> & oldUv );
+
+   private:
+      vector<int> m_oldUv;
+      vector<int> m_newUv;
+};
+
 class MU_Hide : public ModelUndo
 {
    public:
@@ -244,7 +265,7 @@ class MU_MovePrimitive : public ModelUndo
 
       unsigned size();
 
-      typedef enum _MoveType_e
+      enum _MoveType_e
       {
           MT_Vertex,
           MT_Joint,
@@ -1048,6 +1069,29 @@ class MU_SetAnimFPS : public ModelUndo
       double   m_oldFPS;
 };
 
+class MU_SetAnimLoop : public ModelUndo
+{
+   public:
+
+      MU_SetAnimLoop();
+      virtual ~MU_SetAnimLoop();
+
+      void undo( Model * );
+      void redo( Model * );
+      bool combine( Undo * );
+
+      unsigned size();
+
+      void setAnimLoop( Model::AnimationModeE mode, unsigned animNum, bool newLoop, bool oldLoop );
+
+   private:
+
+      Model::AnimationModeE m_mode;
+      unsigned m_animNum;
+      bool   m_newLoop;
+      bool   m_oldLoop;
+};
+
 class MU_SetAnimKeyframe : public ModelUndo
 {
    public:
