@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -23,6 +23,7 @@
 
 #include "objfilter.h"
 
+#include "../mm3dcore/version.h"
 #include "model.h"
 #include "texture.h"
 #include "log.h"
@@ -30,8 +31,6 @@
 #include "misc.h"
 #include "filtermgr.h"
 #include "mm3dport.h"
-#include "datadest.h"
-#include "datasource.h"
 #include "release_ptr.h"
 
 #include <stdio.h>
@@ -48,17 +47,17 @@ using std::string;
 static ObjFilter * s_filter = NULL;
 #endif // PLUGIN
 
-// FIXME centralize this
-template<typename T>
-class FunctionCaller
+namespace {
+
+void replace( char * str, char this_char, char that_char )
 {
-   public:
-      FunctionCaller( T * obj, void (T::*method)(void) ) { m_obj = obj; m_method = method; }
-      ~FunctionCaller() { (m_obj->*m_method)(); }
-   private:
-      T * m_obj;
-      void (T::*m_method)(void);
-};
+   size_t len = strlen(str);
+   for ( size_t t = 0; t < len; ++t )
+      if ( str[t] == this_char )
+         str[t] = that_char;
+}
+
+}
 
 ObjFilter::ObjOptions::ObjOptions()
    : m_saveNormals( true ),
@@ -101,7 +100,7 @@ Model::ModelErrorE ObjFilter::readFile( Model * model, const char * const filena
 {
    Model::ModelErrorE err = Model::ERROR_NONE;
    m_src = openInput( filename, err );
-   FunctionCaller<DataSource> fc( m_src, &DataSource::close );
+   SourceCloser fc( m_src );
 
    if ( err != Model::ERROR_NONE )
       return err;
@@ -142,7 +141,7 @@ Model::ModelErrorE ObjFilter::writeFile( Model * model, const char * const filen
 {
    Model::ModelErrorE err = Model::ERROR_NONE;
    m_dst = openOutput( filename, err );
-   FunctionCaller<DataDest> fc( m_dst, &DataDest::close );
+   DestCloser fc( m_dst );
 
    if ( err != Model::ERROR_NONE )
       return err;
@@ -184,11 +183,7 @@ bool ObjFilter::writeLine( const char * line, ... )
    va_start( ap, line );
    m_dst->writeVPrintf( line, ap );
    va_end( ap );
-#ifdef WIN32
-   m_dst->writePrintf( "\n" );
-#else // WIN32
    m_dst->writePrintf( "\r\n" );
-#endif // WIN32
    return true;
 }
 
@@ -210,6 +205,7 @@ bool ObjFilter::writeStripped( const char * fmt, ... )
    va_list ap;
    va_start( ap, fmt );
    PORT_vsnprintf( line, sizeof(line), fmt, ap );
+   replace( line, ',', '.' );
    va_end( ap );
 
    OFWS_StateE state = OFWS_Whitespace;
@@ -328,11 +324,7 @@ bool ObjFilter::writeStripped( const char * fmt, ... )
    }
    line2[ d ] = '\0';
 
-#ifdef WIN32
-   m_dst->writePrintf( "%s\n", line2 );
-#else // WIN32
    m_dst->writePrintf( "%s\r\n", line2 );
-#endif // WIN32
 
    return true;
 }
@@ -341,7 +333,7 @@ bool ObjFilter::writeHeader()
 {
    writeLine( "# Wavefront OBJ file" );
 
-   writeLine( "# Exported by Misfit Model 3D %s", VERSION );
+   writeLine( "# Exported by Maverick Model 3D %s", VERSION );
 
    time_t tval;
    struct tm tmval;
@@ -691,7 +683,7 @@ void ObjFilter::addObjMaterial( ObjMaterial * objmat )
    }
 }
 
-const char * ObjFilter::skipSpace( const char * str )
+char * ObjFilter::skipSpace( char * str )
 {
    if ( str )
    {
@@ -703,17 +695,19 @@ const char * ObjFilter::skipSpace( const char * str )
    return str;
 }
 
-bool ObjFilter::readLine( const char * line )
+bool ObjFilter::readLine( char * line )
 {
-   const char * str = skipSpace( line );
+   char * str = skipSpace( line );
 
    if ( strncmp( str, "v ", 2 ) == 0 )
    {
       m_vertices++;
+      replace( str, ',', '.' );
       readVertex( str );
    }
-   if ( strncmp( str, "vt ", 3 ) == 0 )
+   else if ( strncmp( str, "vt ", 3 ) == 0 )
    {
+      replace( str, ',', '.' );
       readTextureCoord( str );
    }
    else if ( strncmp( str, "f ", 2 ) == 0 )
@@ -737,7 +731,7 @@ bool ObjFilter::readLine( const char * line )
    return true;
 }
 
-bool ObjFilter::readVertex( const char * line )
+bool ObjFilter::readVertex( char * line )
 {
    line += 2;
    float x, y, z;
@@ -749,7 +743,7 @@ bool ObjFilter::readVertex( const char * line )
    return false;
 }
 
-bool ObjFilter::readTextureCoord( const char * line )
+bool ObjFilter::readTextureCoord( char * line )
 {
    line += 3;
    UvDataT uvd;
@@ -766,7 +760,7 @@ bool ObjFilter::readTextureCoord( const char * line )
    return true;
 }
 
-bool ObjFilter::readFace( const char * line )
+bool ObjFilter::readFace( char * line )
 {
    line += 2;
    std::vector<int> vlist;
@@ -886,7 +880,7 @@ bool ObjFilter::readFace( const char * line )
    return true;
 }
 
-bool ObjFilter::readGroup( const char * line )
+bool ObjFilter::readGroup( char * line )
 {
    int lastGroup = m_curGroup;
    m_needGroup = false;
@@ -948,7 +942,7 @@ bool ObjFilter::readGroup( const char * line )
    return true;
 }
 
-bool ObjFilter::readLibrary( const char * line )
+bool ObjFilter::readLibrary( char * line )
 {
    char filename[256];
 
@@ -984,7 +978,7 @@ bool ObjFilter::readLibrary( const char * line )
    return true;
 }
 
-bool ObjFilter::readMaterial( const char * line )
+bool ObjFilter::readMaterial( char * line )
 {
    char * temp = strdup( line );
    char * ptr = temp;
@@ -1096,7 +1090,9 @@ bool ObjFilter::readMaterialLibrary( const char * filename )
          }
          ptr[0] = '\0';
 
-         objmat->textureMap = m_modelPath + std::string("/") + fixFileCase( m_modelPath.c_str(), filename );
+         replaceBackslash(filename);
+         const string relativePath = fixFileCase( m_modelPath.c_str(), filename );
+         objmat->textureMap = getAbsolutePath( m_modelPath.c_str(), relativePath.c_str() );
          log_debug( "  texture map is '%s'\n", objmat->textureMap.c_str() );
       }
       else if ( strncmp( "Kd ", ptr, 3 ) == 0 )
@@ -1160,7 +1156,7 @@ bool ObjFilter::readMaterialLibrary( const char * filename )
 // Plugin functions
 //------------------------------------------------------------------
 
-extern "C" bool plugin_init()
+PLUGIN_API bool plugin_init()
 {
    if ( s_filter == NULL )
    {
@@ -1174,19 +1170,24 @@ extern "C" bool plugin_init()
 
 // The filter manager will delete our registered filter.
 // We have no other cleanup to do
-extern "C" bool plugin_uninit()
+PLUGIN_API bool plugin_uninit()
 {
    s_filter = NULL; // FilterManager deletes filters
    log_debug( "OBJ model filter plugin uninitialized\n" );
    return true;
 }
 
-extern "C" const char * plugin_version()
+PLUGIN_API const char * plugin_mm3d_version()
+{
+   return VERSION_STRING;
+}
+
+PLUGIN_API const char * plugin_version()
 {
    return "0.1.0";
 }
 
-extern "C" const char * plugin_desc()
+PLUGIN_API const char * plugin_desc()
 {
    return "OBJ model filter";
 }
