@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -24,7 +24,7 @@
 #ifndef __MENUCONF_H
 #define __MENUCONF_H
 
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
 #include "config.h"
 
