@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -43,7 +43,7 @@ typedef vector<int> IntList;
 static string _getWriteFileName( const char * file )
 {
    string s = file;
-   char * ext = strrchr( file, '.' );
+   const char * ext = strrchr( file, '.' );
 
    if ( ext == NULL )
    {
